function plotPorePressure()
% plot various parameters as they vary with depth
close all

% load data
pwp = load('../porepressure.out');

% remove time column from data
allTimes = pwp(:,1);
pwp(:,1) = [];
[nStep, nNodes] = size(pwp);

% extract porepressure nodes on left boundary of model
pwpNodes = 1:6:61;
p = zeros(nStep,length(pwpNodes));
for k = 1:length(pwpNodes)
    p(:,k) = pwp(:,pwpNodes(k));
end

% define vector of nodal depths
depth = linspace(10,0,11)';

% plot excess pore pressure with depth (for clarity only every other step is plotted)
figure(1)
hold on
for k = 5:2:nStep
  % initial step is blue
    if k == 5
        plot(p(k,:),depth,'-bo','linewidth',1.5,'markerfacecolor','w')
  % next 10 steps are green
    elseif k <= 20 && k >= 5
        plot( p(k,:),depth,'-go','linewidth',1.5,'markerfacecolor','w')
  % following steps are red
    elseif k > 20 && k < nStep-1
        plot( p(k,:),depth,'-ro','linewidth',1.5,'markerfacecolor','w')
  %  final step is black
     else
        plot( p(k,:),depth,'-ko','linewidth',1.5,'markerfacecolor','w')
    end
end
grid on
box on
xlabel('pore pressure (kPa)','fontsize',16)
ylabel('depth (m)','fontsize',16)
set(gca,'YDir','reverse','fontsize',16)

return 
