function plotStress()
% creates plots of horizontal and vertical stresses with depth during consolidation
close all

% load data
stress = load('../stress.out');

% remove time column from the data
allTimes = stress(:,1);
stress(:,1) = [];

% data descriptors
[nStep, nValue] = size(stress);
nStress = 5;
nElem   = nValue/nStress;

% reshape the data
s = reshape(stress, nStep, nStress, nElem);

h = zeros(nStep,nElem);
v = zeros(nStep,nElem);
for i = 1:nStep
    for j = 1:nElem
        h(i,j) = -s(i,1,j);
        v(i,j) = -s(i,2,j);
    end
end

% define vector of depths (use center of elements)
depth = linspace(9.5,0.5,nElem)';

% plot horizontal stress with depth
figure(1)
hold on
for k = 1:2:nStep
  % initial step is blue
    if k == 1
        plot(h(k,:), depth,'-bo','linewidth',1.5,'markerfacecolor','w')
  % next 10 steps are green
    elseif k <= 20 && k >= 2
        plot(h(k,:), depth,'-go','linewidth',1.5,'markerfacecolor','w')
  % following steps are red
    elseif k > 10 && k < nStep-1
        plot(h(k,:), depth,'-ro','linewidth',1.5,'markerfacecolor','w')
  %  final step is black
     else
        plot(h(k,:), depth,'-ko','linewidth',1.5,'markerfacecolor','w')
    end
end
grid on
box on
xlabel('horizontal stress (kPa)','fontsize',16)
ylabel('depth (m)','fontsize',16)
set(gca,'YDir','reverse','fontsize',16)

% plot vertical stress with depth
figure(2)
hold on
for k = 5:2:nStep
  % initial step is blue
    if k == 5
        plot(v(k,:), depth,'-bo','linewidth',1.5,'markerfacecolor','w')
  % next 10 steps are green
    elseif k <= 20 && k >= 5
        plot(v(k,:), depth,'-go','linewidth',1.5,'markerfacecolor','w')
  % following steps are red
    elseif k > 20 && k < nStep-1
        plot(v(k,:),depth,'-ro','linewidth',1.5,'markerfacecolor','w')
  %  final step is black
     else
        plot(v(k,:), depth,'-ko','linewidth',1.5,'markerfacecolor','w')
    end
end
grid on
box on
xlabel('vertical effective stress (kPa)','fontsize',16)
ylabel('depth (m)','fontsize',16)
set(gca,'YDir','reverse','fontsize',16)

return
